// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: gps.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_gps_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_gps_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3014000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3014000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "time.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_gps_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_gps_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern GZ_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_gps_2eproto;
namespace gazebo {
namespace msgs {
class GPS;
class GPSDefaultTypeInternal;
GZ_MSGS_VISIBLE extern GPSDefaultTypeInternal _GPS_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::GPS* Arena::CreateMaybeMessage<::gazebo::msgs::GPS>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE GPS PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.GPS) */ {
 public:
  inline GPS() : GPS(nullptr) {}
  virtual ~GPS();

  GPS(const GPS& from);
  GPS(GPS&& from) noexcept
    : GPS() {
    *this = ::std::move(from);
  }

  inline GPS& operator=(const GPS& from) {
    CopyFrom(from);
    return *this;
  }
  inline GPS& operator=(GPS&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const GPS& default_instance();

  static inline const GPS* internal_default_instance() {
    return reinterpret_cast<const GPS*>(
               &_GPS_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(GPS& a, GPS& b) {
    a.Swap(&b);
  }
  inline void Swap(GPS* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(GPS* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline GPS* New() const final {
    return CreateMaybeMessage<GPS>(nullptr);
  }

  GPS* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<GPS>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const GPS& from);
  void MergeFrom(const GPS& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(GPS* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.GPS";
  }
  protected:
  explicit GPS(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    ::PROTOBUF_NAMESPACE_ID::internal::AssignDescriptors(&::descriptor_table_gps_2eproto);
    return ::descriptor_table_gps_2eproto.file_level_metadata[kIndexInFileMessages];
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kLinkNameFieldNumber = 2,
    kTimeFieldNumber = 1,
    kLatitudeDegFieldNumber = 3,
    kLongitudeDegFieldNumber = 4,
    kAltitudeFieldNumber = 5,
    kVelocityEastFieldNumber = 6,
    kVelocityNorthFieldNumber = 7,
    kVelocityUpFieldNumber = 8,
  };
  // required string link_name = 2;
  bool has_link_name() const;
  private:
  bool _internal_has_link_name() const;
  public:
  void clear_link_name();
  const std::string& link_name() const;
  void set_link_name(const std::string& value);
  void set_link_name(std::string&& value);
  void set_link_name(const char* value);
  void set_link_name(const char* value, size_t size);
  std::string* mutable_link_name();
  std::string* release_link_name();
  void set_allocated_link_name(std::string* link_name);
  private:
  const std::string& _internal_link_name() const;
  void _internal_set_link_name(const std::string& value);
  std::string* _internal_mutable_link_name();
  public:

  // required .gazebo.msgs.Time time = 1;
  bool has_time() const;
  private:
  bool _internal_has_time() const;
  public:
  void clear_time();
  const ::gazebo::msgs::Time& time() const;
  ::gazebo::msgs::Time* release_time();
  ::gazebo::msgs::Time* mutable_time();
  void set_allocated_time(::gazebo::msgs::Time* time);
  private:
  const ::gazebo::msgs::Time& _internal_time() const;
  ::gazebo::msgs::Time* _internal_mutable_time();
  public:
  void unsafe_arena_set_allocated_time(
      ::gazebo::msgs::Time* time);
  ::gazebo::msgs::Time* unsafe_arena_release_time();

  // required double latitude_deg = 3;
  bool has_latitude_deg() const;
  private:
  bool _internal_has_latitude_deg() const;
  public:
  void clear_latitude_deg();
  double latitude_deg() const;
  void set_latitude_deg(double value);
  private:
  double _internal_latitude_deg() const;
  void _internal_set_latitude_deg(double value);
  public:

  // required double longitude_deg = 4;
  bool has_longitude_deg() const;
  private:
  bool _internal_has_longitude_deg() const;
  public:
  void clear_longitude_deg();
  double longitude_deg() const;
  void set_longitude_deg(double value);
  private:
  double _internal_longitude_deg() const;
  void _internal_set_longitude_deg(double value);
  public:

  // required double altitude = 5;
  bool has_altitude() const;
  private:
  bool _internal_has_altitude() const;
  public:
  void clear_altitude();
  double altitude() const;
  void set_altitude(double value);
  private:
  double _internal_altitude() const;
  void _internal_set_altitude(double value);
  public:

  // optional double velocity_east = 6;
  bool has_velocity_east() const;
  private:
  bool _internal_has_velocity_east() const;
  public:
  void clear_velocity_east();
  double velocity_east() const;
  void set_velocity_east(double value);
  private:
  double _internal_velocity_east() const;
  void _internal_set_velocity_east(double value);
  public:

  // optional double velocity_north = 7;
  bool has_velocity_north() const;
  private:
  bool _internal_has_velocity_north() const;
  public:
  void clear_velocity_north();
  double velocity_north() const;
  void set_velocity_north(double value);
  private:
  double _internal_velocity_north() const;
  void _internal_set_velocity_north(double value);
  public:

  // optional double velocity_up = 8;
  bool has_velocity_up() const;
  private:
  bool _internal_has_velocity_up() const;
  public:
  void clear_velocity_up();
  double velocity_up() const;
  void set_velocity_up(double value);
  private:
  double _internal_velocity_up() const;
  void _internal_set_velocity_up(double value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.GPS)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr link_name_;
  ::gazebo::msgs::Time* time_;
  double latitude_deg_;
  double longitude_deg_;
  double altitude_;
  double velocity_east_;
  double velocity_north_;
  double velocity_up_;
  friend struct ::TableStruct_gps_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// GPS

// required .gazebo.msgs.Time time = 1;
inline bool GPS::_internal_has_time() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || time_ != nullptr);
  return value;
}
inline bool GPS::has_time() const {
  return _internal_has_time();
}
inline const ::gazebo::msgs::Time& GPS::_internal_time() const {
  const ::gazebo::msgs::Time* p = time_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::Time&>(
      ::gazebo::msgs::_Time_default_instance_);
}
inline const ::gazebo::msgs::Time& GPS::time() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.time)
  return _internal_time();
}
inline void GPS::unsafe_arena_set_allocated_time(
    ::gazebo::msgs::Time* time) {
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(time_);
  }
  time_ = time;
  if (time) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.GPS.time)
}
inline ::gazebo::msgs::Time* GPS::release_time() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Time* temp = time_;
  time_ = nullptr;
  if (GetArena() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
  return temp;
}
inline ::gazebo::msgs::Time* GPS::unsafe_arena_release_time() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPS.time)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Time* temp = time_;
  time_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Time* GPS::_internal_mutable_time() {
  _has_bits_[0] |= 0x00000002u;
  if (time_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Time>(GetArena());
    time_ = p;
  }
  return time_;
}
inline ::gazebo::msgs::Time* GPS::mutable_time() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPS.time)
  return _internal_mutable_time();
}
inline void GPS::set_allocated_time(::gazebo::msgs::Time* time) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArena();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(time_);
  }
  if (time) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
      reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(time)->GetArena();
    if (message_arena != submessage_arena) {
      time = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, time, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  time_ = time;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPS.time)
}

// required string link_name = 2;
inline bool GPS::_internal_has_link_name() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool GPS::has_link_name() const {
  return _internal_has_link_name();
}
inline void GPS::clear_link_name() {
  link_name_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& GPS::link_name() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.link_name)
  return _internal_link_name();
}
inline void GPS::set_link_name(const std::string& value) {
  _internal_set_link_name(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.link_name)
}
inline std::string* GPS::mutable_link_name() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.GPS.link_name)
  return _internal_mutable_link_name();
}
inline const std::string& GPS::_internal_link_name() const {
  return link_name_.Get();
}
inline void GPS::_internal_set_link_name(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  link_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArena());
}
inline void GPS::set_link_name(std::string&& value) {
  _has_bits_[0] |= 0x00000001u;
  link_name_.Set(
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:gazebo.msgs.GPS.link_name)
}
inline void GPS::set_link_name(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  _has_bits_[0] |= 0x00000001u;
  link_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::string(value), GetArena());
  // @@protoc_insertion_point(field_set_char:gazebo.msgs.GPS.link_name)
}
inline void GPS::set_link_name(const char* value,
    size_t size) {
  _has_bits_[0] |= 0x00000001u;
  link_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:gazebo.msgs.GPS.link_name)
}
inline std::string* GPS::_internal_mutable_link_name() {
  _has_bits_[0] |= 0x00000001u;
  return link_name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArena());
}
inline std::string* GPS::release_link_name() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.GPS.link_name)
  if (!_internal_has_link_name()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return link_name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void GPS::set_allocated_link_name(std::string* link_name) {
  if (link_name != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  link_name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), link_name,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.GPS.link_name)
}

// required double latitude_deg = 3;
inline bool GPS::_internal_has_latitude_deg() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool GPS::has_latitude_deg() const {
  return _internal_has_latitude_deg();
}
inline void GPS::clear_latitude_deg() {
  latitude_deg_ = 0;
  _has_bits_[0] &= ~0x00000004u;
}
inline double GPS::_internal_latitude_deg() const {
  return latitude_deg_;
}
inline double GPS::latitude_deg() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.latitude_deg)
  return _internal_latitude_deg();
}
inline void GPS::_internal_set_latitude_deg(double value) {
  _has_bits_[0] |= 0x00000004u;
  latitude_deg_ = value;
}
inline void GPS::set_latitude_deg(double value) {
  _internal_set_latitude_deg(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.latitude_deg)
}

// required double longitude_deg = 4;
inline bool GPS::_internal_has_longitude_deg() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool GPS::has_longitude_deg() const {
  return _internal_has_longitude_deg();
}
inline void GPS::clear_longitude_deg() {
  longitude_deg_ = 0;
  _has_bits_[0] &= ~0x00000008u;
}
inline double GPS::_internal_longitude_deg() const {
  return longitude_deg_;
}
inline double GPS::longitude_deg() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.longitude_deg)
  return _internal_longitude_deg();
}
inline void GPS::_internal_set_longitude_deg(double value) {
  _has_bits_[0] |= 0x00000008u;
  longitude_deg_ = value;
}
inline void GPS::set_longitude_deg(double value) {
  _internal_set_longitude_deg(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.longitude_deg)
}

// required double altitude = 5;
inline bool GPS::_internal_has_altitude() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool GPS::has_altitude() const {
  return _internal_has_altitude();
}
inline void GPS::clear_altitude() {
  altitude_ = 0;
  _has_bits_[0] &= ~0x00000010u;
}
inline double GPS::_internal_altitude() const {
  return altitude_;
}
inline double GPS::altitude() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.altitude)
  return _internal_altitude();
}
inline void GPS::_internal_set_altitude(double value) {
  _has_bits_[0] |= 0x00000010u;
  altitude_ = value;
}
inline void GPS::set_altitude(double value) {
  _internal_set_altitude(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.altitude)
}

// optional double velocity_east = 6;
inline bool GPS::_internal_has_velocity_east() const {
  bool value = (_has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool GPS::has_velocity_east() const {
  return _internal_has_velocity_east();
}
inline void GPS::clear_velocity_east() {
  velocity_east_ = 0;
  _has_bits_[0] &= ~0x00000020u;
}
inline double GPS::_internal_velocity_east() const {
  return velocity_east_;
}
inline double GPS::velocity_east() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.velocity_east)
  return _internal_velocity_east();
}
inline void GPS::_internal_set_velocity_east(double value) {
  _has_bits_[0] |= 0x00000020u;
  velocity_east_ = value;
}
inline void GPS::set_velocity_east(double value) {
  _internal_set_velocity_east(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.velocity_east)
}

// optional double velocity_north = 7;
inline bool GPS::_internal_has_velocity_north() const {
  bool value = (_has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool GPS::has_velocity_north() const {
  return _internal_has_velocity_north();
}
inline void GPS::clear_velocity_north() {
  velocity_north_ = 0;
  _has_bits_[0] &= ~0x00000040u;
}
inline double GPS::_internal_velocity_north() const {
  return velocity_north_;
}
inline double GPS::velocity_north() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.velocity_north)
  return _internal_velocity_north();
}
inline void GPS::_internal_set_velocity_north(double value) {
  _has_bits_[0] |= 0x00000040u;
  velocity_north_ = value;
}
inline void GPS::set_velocity_north(double value) {
  _internal_set_velocity_north(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.velocity_north)
}

// optional double velocity_up = 8;
inline bool GPS::_internal_has_velocity_up() const {
  bool value = (_has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool GPS::has_velocity_up() const {
  return _internal_has_velocity_up();
}
inline void GPS::clear_velocity_up() {
  velocity_up_ = 0;
  _has_bits_[0] &= ~0x00000080u;
}
inline double GPS::_internal_velocity_up() const {
  return velocity_up_;
}
inline double GPS::velocity_up() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.GPS.velocity_up)
  return _internal_velocity_up();
}
inline void GPS::_internal_set_velocity_up(double value) {
  _has_bits_[0] |= 0x00000080u;
  velocity_up_ = value;
}
inline void GPS::set_velocity_up(double value) {
  _internal_set_velocity_up(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.GPS.velocity_up)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::GPS> GPSPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::GPS const> ConstGPSPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_gps_2eproto
